#ifndef AcpiWidget_h
#define AcpiWidget_h
// $Id: AcpiWidget.h,v 1.20 2014/02/10 10:41:08 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Acpi.h"
#include "MainWindow.h"

#include <QBasicTimer>
#include <QLabel>
#include <QProgressBar>
#include <QTimerEvent>

//! battery monitor
namespace Acpi
{

    //! display a set of log entries, allows selection of one
    class AcpiWidget: public MainWindow
    {

        Q_OBJECT

        public:

        //! constructor
        AcpiWidget( QWidget *parent = 0 );

        //! destructor
        virtual ~AcpiWidget( void )
        {}

        protected:

        //! timer event
        void timerEvent( QTimerEvent* );

        //!@name actions
        //@{

        //! update
        QAction& _updateAction( void )
        { return *updateAction_; }

        //! label
        QAction& _showLabelAction( void )
        { return *showLabelAction_; }

        //@}

        //! paint
        void _paint(QPaintDevice&, const QRect&);

        //! context menu
        virtual void _installContextMenuActions( BaseContextMenu* );

        //! tooltip
        virtual bool _updateToolTip( void );

        protected Q_SLOTS:

        //! opend configuration dialog
        virtual void _configuration( void );

        //! update configuration
        virtual void _updateConfiguration( void );

        //! toggle show/hide label
        void _toggleLabel( bool );

        //! update
        void _update( void );

        protected:

        //! progressbar
        QProgressBar& _progressBar( void ) const
        { return *progressBar_; }

        //! label
        QLabel& _label( void ) const
        { return *label_; }

        //! render widget
        void _render( QPaintDevice&, QWidget&, const QRect& );

        private:

        //! install actions
        void _installActions( void );

        //! acpi
        Acpi acpi_;

        //!@name actions
        //@{

        //! update action
        QAction* updateAction_;

        //! show/hide label
        QAction* showLabelAction_;

        //@}

        //! label
        QLabel *label_;

        //! progress bar
        QProgressBar *progressBar_;

        //! pixmap
        QPixmap battery_;

        //! color map
        typedef QHash< Acpi::Level, QColor > ColorMap;
        ColorMap colors_;

        //! pixmap map
        typedef QHash< Acpi::State, QPixmap > PixmapMap;

        //! pixmap map
        PixmapMap pixmaps_;

        //@}
    };
};

#endif
