// $Id: EditCalendarEventDialog.cpp,v 1.9 2014/02/10 10:07:45 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "EditCalendarEventDialog.h"
#include "EditCalendarEventDialog.moc"
#include "GridLayout.h"

#include <QLabel>
#include <QButtonGroup>

namespace Calendar
{

    //___________________________________________
    EditCalendarEventDialog::EditCalendarEventDialog( QWidget* parent, const CalendarEvent& event ):
        CustomDialog( parent )
    {
        Debug::Throw( "EditCalendarEventDialog::EditCalendarEventDialog.\n" );
        setWindowTitle( tr( "Event - Calendar" ) );
        setOptionName( "CALENDAR_TAG_DIALOG" );

        QGridLayout* grid = new QGridLayout();
        grid->setSpacing( 5 );
        grid->setMargin( 0 );
        mainLayout().addLayout( grid );

        // running row
        int row(0);

        // begin date edition
        QLabel* label;
        grid->addWidget( label = new QLabel( tr( "From:" ), this ), row, 0, 1, 1 );
        grid->addWidget( beginEditor_ = new QDateEdit( this ), row, 1, 1, 1 );
        beginEditor_->setDisplayFormat( "MMMM dd yyyy" );
        label->setBuddy( beginEditor_ );
        label->setAlignment( Qt::AlignVCenter|Qt::AlignRight );

        grid->addWidget( beginTimeEditor_ = new QTimeEdit( this ), row, 2, 1, 1 );

        if( event.begin().isValid() )
        {
            beginEditor_->setDateTime( event.begin() );
            beginTimeEditor_->setDateTime( event.begin() );
        }

        // end date edition
        ++row;
        grid->addWidget( label = new QLabel( tr( "To:" ), this ), row, 0, 1, 1 );
        grid->addWidget( endEditor_ = new QDateEdit( this ), row, 1, 1, 1 );
        endEditor_->setDisplayFormat( "MMMM dd yyyy" );
        label->setBuddy( endEditor_ );
        label->setAlignment( Qt::AlignVCenter|Qt::AlignRight );

        grid->addWidget( endTimeEditor_ = new QTimeEdit( this ), row, 2, 1, 1 );

        if( event.end().isValid() )
        {
            endEditor_->setDateTime( event.end() );
            endTimeEditor_->setDateTime( event.end() );
        }

        // full days
        ++row;
        grid->addWidget( fullDaysCheckBox_ = new QCheckBox( tr( "Full days" ) ), row, 1, 1, 2 );
        connect( fullDaysCheckBox_, SIGNAL(toggled(bool)), beginTimeEditor_, SLOT(setDisabled(bool)) );
        connect( fullDaysCheckBox_, SIGNAL(toggled(bool)), endTimeEditor_, SLOT(setDisabled(bool)) );
        fullDaysCheckBox_->setChecked( event.hasFlag( CalendarEvent::FullDays ) );

        // notify
        ++row;
        grid->addWidget( notifyCheckBox_ = new QCheckBox( tr( "Send notification" ) ), row, 1, 1, 2 );
        notifyCheckBox_->setChecked( event.hasFlag( CalendarEvent::Notify ) );

        // selection mode
        {

            ++row;
            grid->addWidget( label = new QLabel( tr( "Selection mode:" ), this ), row, 0, 1, 1 );
            grid->addWidget( selectioncomboBox_ = new QComboBox( this ), row, 1, 1, 1 );
            label->setBuddy( selectioncomboBox_ );
            label->setAlignment( Qt::AlignVCenter|Qt::AlignRight );

            for( CalendarEvent::SelectionMap::const_iterator iter = CalendarEvent::selectionMap().begin(); iter != CalendarEvent::selectionMap().end(); ++iter )
            { selectioncomboBox_->addItem( iter.value() ); }

            selectioncomboBox_->setCurrentIndex( selectioncomboBox_->findText( event.selectionName() ) );

        }

        // repeat mode
        {

            ++row;
            grid->addWidget( label = new QLabel( tr( "Repeat:" ), this ), row, 0, 1, 1 );
            grid->addWidget( repeatcomboBox_ = new QComboBox( this ), row, 1, 1, 1 );
            label->setBuddy( repeatcomboBox_ );
            label->setAlignment( Qt::AlignVCenter|Qt::AlignRight );

            for( CalendarEvent::RepeatMap::const_iterator iter = CalendarEvent::repeatMap().begin(); iter != CalendarEvent::repeatMap().end(); ++iter )
            { repeatcomboBox_->addItem( iter.value() ); }

            repeatcomboBox_->setCurrentIndex( repeatcomboBox_->findText( event.repeatModeName() ) );

        }

        grid->setColumnStretch( 1, 1 );
        grid->setColumnStretch( 2, 1 );

        // text editor
        mainLayout().addWidget( new QLabel( tr( "Description:" ), this ) );
        mainLayout().addWidget( editor_ = new TextEditor( this ) );
        editor_->setText( event.description() );

    }

    //___________________________________________
    CalendarEvent EditCalendarEventDialog::event( void )
    {
        CalendarEvent event;
        event.setRange(
            QDateTime( beginEditor_->date(), beginTimeEditor_->time() ),
            QDateTime( endEditor_->date(), endTimeEditor_->time() ) );

        event.setDescription( editor_->toPlainText() );
        event.setSelectionMode( CalendarEvent::selectionMode( selectioncomboBox_->currentText() ) );
        event.setRepeatMode( CalendarEvent::repeatMode( repeatcomboBox_->currentText() ) );
        event.setFlag( CalendarEvent::FullDays, fullDaysCheckBox_->isChecked() );
        event.setFlag( CalendarEvent::Notify, notifyCheckBox_->isChecked() );

        return event;
    }

}
