// $Id: DiskLoad.cpp,v 1.19 2014/03/21 19:29:38 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DiskLoad.h"

#include <QFile>
#include <QStringList>

namespace Disk
{
    //________________________________________________
    DiskLoad::DiskLoad( void ):
        Counter( "DiskLoad" ),
        sampleSize_( 0 ),
        dataSize_( 0 ),
        mountFilename_( "/etc/mtab" )
    { timer_.start(); }

    //________________________________________________
    DiskLoad::DeviceSet DiskLoad::devices( void )
    {

        update();
        updateMountedDevices();
        DeviceSet out;
        for( IdMap::const_iterator iter = idMap_.begin(); iter != idMap_.end(); ++iter )
        { if( isMounted( iter.key() ) ) out.insert( iter.key() ); }

        return out;

    }

    //________________________________________________
    void DiskLoad::updateMountedDevices( void )
    {

        Debug::Throw( "DiskLoad::updateMountedDevices.\n" );

        // clear old set
        mountedDevices_.clear();

        // open file
        QFile in( mountFilename_ );
        if( !in.open( QIODevice::ReadOnly ) )
        { return; }

        QStringList lines( QString( in.readAll() ).split( "\n" ) );
        for( QStringList::iterator iter = lines.begin(); iter != lines.end(); ++iter )
        {

            QString device;
            QTextStream stream( &*iter );
            stream >> device;
            if( stream.status() != QTextStream::Ok ) continue;

            mountedDevices_.insert( device );

        }

    }


    //________________________________________________
    bool DiskLoad::isMounted( const QString& device ) const
    {
        for( DeviceSet::const_iterator iter = mountedDevices_.begin(); iter != mountedDevices_.end(); ++iter )
        { if( (*iter).indexOf( device ) >= 0 ) return true; }

        return false;
    }

    //________________________________________________
    QString DiskLoad::toString( double value )
    {

        // add sector size. Assume 512 bytes
        static const double sector_size = 512;
        value *= sector_size;

        QString unit( QObject::tr( "bps" ) );
        if( value > 1024 ) { value/=1024; unit = QObject::tr( "kbps" ); }
        if( value > 1024 ) { value/=1024; unit = QObject::tr( "Mbps" ); }
        return QString( "%1 %2" ).arg( QString::number( value, 'f', 1 ) ).arg( unit );

    }

}
