#ifndef PictureApplication_h
#define PictureApplication_h

// $Id: PictureApplication.h,v 1.24 2014/02/10 10:34:30 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Counter.h"
#include "IconEngine.h"

namespace Pictures { class PictureWidget; }

//! Main Window singleton object
class PictureApplication: public BaseApplication, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    PictureApplication( CommandLineArguments );

    //! destructor
    virtual ~PictureApplication( void );

    //! create all widgets
    virtual bool realizeWidget( void );

    //!@name actions
    //@{

    //! raise all
    QAction& raiseAllAction( void ) const
    { return *raiseAllAction_; }

    //! new picture
    QAction& newPictureAction( void ) const
    { return *newPictureAction_; }

    //! picture list
    QAction& pictureListAction( void ) const
    { return *pictureListAction_; }

    //! aspect ratio
    QAction& keepAspectRatioAction( void ) const
    { return *keepAspectRatioAction_; }

    //! toggle filename action
    QAction& showFilenameAction( void ) const
    { return *showFileNameAction_; }

    //@}

    //!@name application information
    //@{

    //! usage
    void usage( void ) const;

    //! application name
    virtual QString applicationName( void ) const;

    //! application icon
    virtual QIcon applicationIcon( void ) const
    { return IconEngine::get( ":/transparent-picture-viewer.png" ); }

    // application version
    virtual QString applicationVersion( void ) const;

    // build time stamp
    virtual QString buildTimeStamp( void ) const;

    //@}

    protected Q_SLOTS:

    //! configuration
    virtual void _configuration( void );

    //! process request from application manager
    virtual bool _processCommand( Server::ServerCommand );

    private Q_SLOTS:

    //! raise all
    void _raiseAll( void );

    //! configuration
    void _updateConfiguration( void );

    //! write pictures from resource files
    void _writePictures(  bool check = true );

    //! create a new task bar from attributes
    void _newPicture( void );

    //! picture list
    void _showPictureList( void );

    //! picture is destroyed
    void _pictureDestroyed( QObject* );

    //! toggle aspect ratio
    void _toggleKeepAspectRatio( bool );

    //! toggle filename
    void _toggleShowFilename( bool );

    //! one picture has been hidden
    void _pictureHidden( void );

    private:

    //! actions
    void _installActions( void );

    //! add a picture
    void _addPicture( Pictures::PictureWidget* );

    //! read pictures from resource files
    void _readPictures( void );

    //! picture widgets
    QList<Pictures::PictureWidget*> pictureWidgets_;

    //!@name actions
    //@{

    //! raise all action
    QAction* raiseAllAction_;

    //! new picture
    QAction* newPictureAction_;

    //! picture list
    QAction* pictureListAction_;

    //! aspect ratio
    QAction* keepAspectRatioAction_;

    //! filename
    QAction* showFileNameAction_;

    //@}

};

#endif
