
// $Id: NetworkConfigurationDialog.cpp,v 1.35 2014/03/16 11:17:03 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "NetworkConfigurationDialog.h"
#include "NetworkConfigurationDialog.moc"

#include "GridLayout.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "OptionCheckBox.h"
#include "OptionColorDisplay.h"
#include "OptionSlider.h"
#include "OptionSpinBox.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>

namespace Network
{

    //_________________________________________________________
    NetworkConfigurationDialog::NetworkConfigurationDialog( QWidget* parent ):
        ConfigurationDialog( parent )
    {

        Debug::Throw( "NetworkConfigurationDialog::NetworkConfigurationDialog.\n" );
        setWindowTitle( tr( "Configuration - Network Monitor" ) );

        // generic widgets
        QWidget* page;
        QWidget *box;
        OptionColorDisplay *colorDisplay;
        OptionCheckBox* checkbox;
        OptionSlider* slider;

        page = &addPage( IconEngine::get( IconNames::PreferencesAppearance), tr( "Appearance" ), tr( "Window appearance and colors" ) );
        page->layout()->addWidget( box = new QGroupBox( tr( "Colors" ), page ));

        QVBoxLayout* vLayout( new QVBoxLayout() );
        vLayout->setSpacing(5);
        vLayout->setMargin(5);
        box->setLayout( vLayout );

        // use default colors
        vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Use default colors" ), box, "USE_DEFAULT_COLORS" ) );
        addOptionWidget( checkbox );

        box = new QWidget( box );
        vLayout->addWidget( box );

        GridLayout* gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(0);
        gridLayout->setMaxCount( 2 );
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        box->setLayout( gridLayout );

        // reception color
        QLabel* label;
        gridLayout->addWidget( label = new QLabel( tr( "Reception:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "RECEIVED_COLOR" ) );
        addOptionWidget( colorDisplay );
        label->setBuddy( colorDisplay );

        connect( checkbox, SIGNAL(toggled(bool)), label, SLOT(setDisabled(bool)) );
        connect( checkbox, SIGNAL(toggled(bool)), colorDisplay, SLOT(setDisabled(bool)) );

        // transmission color
        gridLayout->addWidget( label = new QLabel( tr( "Transmission:" ), box ) );
        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "TRANSMITTED_COLOR" ) );
        addOptionWidget( colorDisplay );
        label->setBuddy( colorDisplay );

        connect( checkbox, SIGNAL(toggled(bool)), label, SLOT(setDisabled(bool)) );
        connect( checkbox, SIGNAL(toggled(bool)), colorDisplay, SLOT(setDisabled(bool)) );

        // intensity
        gridLayout->addWidget( label = new QLabel( tr( "Intensity:" ), this ) );
        gridLayout->addWidget( slider = new OptionSlider( this, "TRANSPARENCY_BACKGROUND_INTENSITY" ) );
        slider->setScale( 1.0/2.55 );
        slider->setRange( 0, 100 );
        addOptionWidget( slider );
        label->setBuddy( slider );

        vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Use gradient" ), box, "TRANSPARENCY_USE_GRADIENT" ) );
        addOptionWidget( checkbox );

        // display
        page->layout()->addWidget( box = new QGroupBox( tr( "Display" ), page ));
        vLayout = new QVBoxLayout();
        vLayout->setSpacing(5);
        vLayout->setMargin(5);
        box->setLayout( vLayout );

        vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Reception" ), box, "SHOW_Received" ) );
        addOptionWidget( checkbox );

        vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Transmission" ), box, "SHOW_Transmitted" ) );
        addOptionWidget( checkbox );

        vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Load" ), box, "SHOW_LOAD" ) );
        addOptionWidget( checkbox );

        vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Hostname" ), box, "SHOW_HOST" ) );
        addOptionWidget( checkbox );

        // options
        page->layout()->addWidget( box = new QGroupBox( tr( "Options" ), page ));
        vLayout = new QVBoxLayout();
        vLayout->setSpacing(5);
        vLayout->setMargin(5);
        box->setLayout( vLayout );

        gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(5);
        gridLayout->setMaxCount( 2 );
        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
        vLayout->addLayout( gridLayout );

        OptionSpinBox* spinbox;
        gridLayout->addWidget( label = new QLabel( tr( "Refresh interval:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "REFRESH_RATE" ) );
        spinbox->setSuffix( tr( "s" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Time interval (seconds) between two refresh" ) );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );

        gridLayout->addWidget( label = new QLabel( tr( "Number of samples:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "SAMPLES" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Number of samples averaged for each measurement" ) );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );

        gridLayout->addWidget( label = new QLabel( tr( "Network device check interval:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "NETWORK_AUTO_SELECT_RATE" ) );
        spinbox->setSuffix( tr( "s" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Time interval (seconds) between checks" ) );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );

        read();

    }
}
