// $Id: PictureAttributesModel.cpp,v 1.14 2014/02/18 15:15:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "PictureAttributesModel.h"
#include "PictureAttributesModel.moc"

#include "CustomPixmap.h"
#include "File.h"
#include "XmlOptions.h"

namespace Pictures
{
    //__________________________________________________________________
    PictureAttributesModel::IconCache& PictureAttributesModel::_icons( void )
    {
        static IconCache cache;
        return cache;
    }

    //__________________________________________________
    const QString PictureAttributesModel::columnNames_[PictureAttributesModel::nColumns] =
    {
        QString(),
        tr( "File " ),
        QString()
    };


    //_______________________________________________________________________________________
    QVariant PictureAttributesModel::data( const QModelIndex& index, int role ) const
    {

        // check index, role and column
        if( !index.isValid() ) return QVariant();

        // retrieve associated file info
        PictureAttributes attributes( get()[index.row()] );

        // return text associated to file and column
        if( role == Qt::DisplayRole && index.column() == Filename )
        {

            return File( attributes.filename() ).localName();

        } else if( role == Qt::CheckStateRole && index.column() == Visibility ) {

            return attributes.isVisible() ? Qt::Checked:Qt::Unchecked;

        } else if( role == Qt::DecorationRole && index.column() == Icon ) {

            return _icon( attributes.filename() );

        } else if( role == Qt::ToolTipRole ) return attributes.filename();

        return QVariant();

    }

    //________________________________________________________
    QVariant PictureAttributesModel::headerData( int section, Qt::Orientation orientation, int role ) const
    {

        if( orientation == Qt::Horizontal && role == Qt::DisplayRole && section >= 0 && section < nColumns )
        { return columnNames_[section]; }

        // return empty
        return QVariant();

    }

    //________________________________________________________
    QIcon PictureAttributesModel::_icon( const QString& filename )
    {

        IconCache::const_iterator iter( _icons().find( filename ) );
        if( iter != _icons().end() ) return iter.value();

        // pixmap size
        unsigned int pixmap_size = XmlOptions::get().get<unsigned int>( "LIST_ICON_SIZE" );
        QSize size( pixmap_size, pixmap_size );
        QSize scale(size*0.9);

        QPixmap base( filename );

        QIcon icon;
        if( !base.isNull() )
        { icon = CustomPixmap().empty( size ).merge( base.scaled( scale, Qt::KeepAspectRatio, Qt::SmoothTransformation ), CustomPixmap::CENTER ); }

        // insert in map
        _icons().insert( filename, icon );

        return icon;

    }
}
